#ifndef ARCHIVE_FILTER_H
#define ARCHIVE_FILTER_H

#include "transform.h"

class KArchive;

namespace Konvert
{
//-----------------------------------------------------------------------------
class ArchiveKDETransform : public GenericTransform
{
  Q_OBJECT
public:
  ArchiveKDETransform() {}

  virtual bool supports(TransAction action, const MimeType &mimetype) const;
  virtual bool doAction(TransAction action, const MimeType &mimetype,
                        const ExchangeData &source, const ExchangeData &dest,
                        Filter *filter) const;

private:
  struct Data {
    const char *mimetype;
    bool supported[Nb_TransActions];
  };
  enum Type { Ar = 0, Zip, Tar, Nb_Types };
  static const Data DATA[Nb_Types]; // only supported ones
  static Type type(const MimeType &mimetype);
  static KArchive *factory(const MimeType &mimetype, const QString &filename);
};

//-----------------------------------------------------------------------------
class ArchiveProcessTransform : public ProcessTransform
{
  Q_OBJECT
public:
  enum { Nb_Types = 15 };
  ArchiveProcessTransform(uint i)
    : ProcessTransform(DATA[i]) {}

  virtual bool supports(TransAction action, const MimeType &mimetype) const;
  virtual bool doAction(TransAction action, const MimeType &mimetype,
                        const QString &source, const QString &dest,
                        Filter *filter) const;

private:
  static const Data DATA[Nb_Types];
};

//-----------------------------------------------------------------------------
class ArchiveFilter : public TransformFilter
{
  Q_OBJECT
public:
  static void addFilters(QPtrList<Filter> &list);
  
private:
  static TransformList *_list;
  static const bool SUPPORTED[Nb_Actions];

  ArchiveFilter(Action action);
  virtual bool isSupported(Action action, TransAction tAction,
                           IOType type, const MimeType &mimetype) const;
  virtual void fillList(TransformList &list) const;
};

} // namespace

#endif
