#include "audio_filter.h"

#include <qregexp.h>

#include <kprocess.h>
#include <klocale.h>

using namespace Konvert;

//----------------------------------------------------------------------------
void Konvert::addAudioFilters(QPtrList<Filter> &list)
{
  list.append(new SoxAudioFilter());
}  

//----------------------------------------------------------------------------
const MultiTypeProcessFilter::CodeData SoxAudioFilter::CODE_DATA[] = {
  { "8svx",   0                }, // #### no mimetype
  { "aiff",   "audio/x-aiff"   },
  { "al",     0                }, // raw
  { "alsa",   0                }, // driver
  { "au",     "audio/x-ulaw"   },
  { "auto",   0                }, // internal
  { "avr",    0                }, // #### no mimetype
  { "cdr",    "application/x-cda" },
  { "cvs",    0                }, // #### no mimetype
  { "dat",    0                }, // #### no mimetype
  { "gsm",    0                }, // #### no mimetype
  { "hcom",   0                }, // #### no mimetype
  { "la",     0                }, // raw
  { "lu",     0                }, // raw
  { "maud",   0                }, // #### no mimetype
  { "mp3",    "audio/x-mp3"    },
  { "nul",    0                }, // internal
  { "ogg",    "audio/x-vorbis" },
  { "ossdsp", 0                }, // driver
  { "prc",    0                }, // #### no mimetype
  { "raw",    0                }, // raw
  { "sb",     0                }, // raw
  { "sf",     0                }, // #### no mimetype
  { "sl",     0                }, // raw
  { "sph",    0                }, // #### no mimetype
  { "smp",    0                }, // #### no mimetype
  { "snd",    0                }, // #### no mimetype
  { "sndt",   0                }, // #### no mimetype
  { "sw",     0                }, // raw
  { "sunau",  0                }, // driver
  { "txw",    0                }, // #### no mimetype
  { "ub",     0                }, // raw
  { "ul",     0                }, // raw
  { "uw",     0                }, // raw
  { "vms",    0                }, // #### no mimetype
  { "voc",    "audio/x-voc"    },
  { "vorbis", "audio/x-vorbis" },
  { "wav",    "audio/x-wav"    },
  { "wve",    0                }, // #### no mimetype
  { 0,        0                }
};

const MultiTypeProcessFilter::Data SoxAudioFilter::DATA = {
  {"sox", Stderr, "-h", 0}, true, {CODE_DATA, CODE_DATA}
};

SoxAudioFilter::SoxAudioFilter()
  : MultiTypeProcessFilter(DATA, Convert, Audio)
{}

QStringList SoxAudioFilter::extractCodes(IOType, const QStringList &lines) const
{
  QRegExp regExp("^[\\w\\s]+:\\s+([\\w\\s]+)", true);
  if ( regExp.search(lines.last())!=-1 )
    return QStringList::split(' ', regExp.cap(1));
  return QStringList();
}

QStringList SoxAudioFilter::args(const QString &source, const MimeType &sourceType,
                              const QString &dest, const MimeType &destType) const
{
  QStringList args;
  args.append("-t");
  args.append(findCode(Source, sourceType));
  args.append(source);
  args.append("-t");
  args.append(findCode(Destination, destType));
  args.append(dest);
  return args;
}

#include "audio_filter.moc"
