#ifndef COMPRESS_FILTER_H
#define COMPRESS_FILTER_H

#include "transform.h"

namespace Konvert
{
//-----------------------------------------------------------------------------
class CompressKDETransform : public GenericTransform
{
  Q_OBJECT
public:
  CompressKDETransform() {}

  virtual bool supports( TransAction action, const MimeType &mimetype) const;
  virtual bool doAction(TransAction action, const MimeType &mimetype,
                        const ExchangeData &source, const ExchangeData &dest,
                        Filter *filter) const;
  QIODevice *factory(const MimeType &mimetype, const QString &source) const;

private:
  static QMap<QString, bool> *_supportedCompressions;

  enum { Buffer_Size = 1000 };
  static char BUFFER[Buffer_Size];
  static bool copy(QIODevice &source, QIODevice &dest, Filter *filter);
};

//-----------------------------------------------------------------------------
class CompressProcessTransform : public ProcessTransform
{
  Q_OBJECT
public:
  enum { Nb_Types = 4 };
  CompressProcessTransform(uint i)
    : ProcessTransform(DATA[i]) {}

  virtual bool supports(TransAction action, const MimeType &mimetype) const;
  QIODevice *factory(const MimeType &mimetype, const QString &source) const;

private:
  static const Data DATA[Nb_Types];
};

//-----------------------------------------------------------------------------
class CompressFilter : public TransformFilter
{
  Q_OBJECT
public:
  static void addFilters(QPtrList<Filter> &list);

public:
  virtual QString destFilename(const KURL &source, const MimeType &sourceType,
                               const MimeType &destType) const;
  virtual MimeType destMimetype(const KURL &source, const MimeType &sourceType,
                                const MimeType &destType) const;
  virtual bool isSupported(TransAction action, const MimeType &mimetype) const;
  QIODevice *factory(const MimeType &mimetype, const QString &source) const;

private:
  static TransformList *_list;
  static const bool SUPPORTED[Nb_Actions];

  CompressFilter(Action action);
  virtual bool isSupported(Action action, TransAction tAction, IOType type,
                           const MimeType &mimetype) const;
  virtual void fillList(TransformList &list) const;
};

} // namespace

#endif
