/***************************************************************************
 *   Copyright (C) 2004 by Nicolas Hadacek                                 *
 *   hadacek@kde.org                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CONVERTER_H
#define CONVERTER_H

#include "filter.h"

class KTempFile;
class KTempDir;
namespace KIO {
  class Job;
}

namespace Konvert
{
//-----------------------------------------------------------------------------
class FileItem
{
public:
  FileItem() {}
  FileItem(const KURL &url) { setURL(url); }

  QString name() const { return _url.fileName(); }
  const KURL &url() const { return _url; }
  MimeType mimetype() const { return _mimetype; }
  QPixmap pixmap() const { return _mimetype.pixmap(true); }
  bool isLocal() const { return _url.isLocalFile(); }
  const KURL &localURL() const { return _local; }

  void setURL(const KURL &url);
  void setLocalURL(const KURL &url) { _local = url; }

  KFileItem *item() const;

private:
  KURL     _url, _local;
  MimeType _mimetype;
};

//-----------------------------------------------------------------------------
class Converter : public QObject
{
  Q_OBJECT
public:
  Converter(Filter &filter, const FileItem &source,
            const KURL &destDir, const MimeType &destMimeType,
            QWidget *widget);
  ~Converter();

  void copySource();
  void convert();
  void copyDestination();
  void abort();
  bool oneStepConvert();

  const FileItem &item(IOType type) const { return _items[type]; }
  QString error() const { return _error; }
  bool hasError() const { return !_error.isEmpty(); }

signals:
  void done();

private slots:
  void copySourceDone();
  void convertDoneSlot();
  void listDirDone();
  void copyDestinationDone();

private:
  Filter        &_filter;
  QValueVector<FileItem> _items;
  const KURL     _destDir;
  const MimeType _destMimetype;
  KIO::Job      *_job;
  DirLister     *_lister;

  TempInode      *_tmpSrc, *_tmpDst;
  QString        _error;
  KURL::List    _filesToCopy;

  void setError(Result result, const QString &detailedError = QString::null);
  QWidget *widget();
  void createDestination();
  void copyFiles();
};

} // namespace

#endif
