#include "filter_dialogs.h"

#include <qlayout.h>

#include <klocale.h>
#include <klistview.h>

using namespace Konvert;

//-----------------------------------------------------------------------------
MimetypesDialog::MimetypesDialog(QWidget *parent)
  : KDialogBase(Plain, i18n("Supported Mimetypes"), Close, Close,
                parent, "mimetypes_dialog", false)
{
  QGridLayout *grid = new QGridLayout(plainPage(), 1, 2);

  _sourceList = new KListView(plainPage());
  _sourceList->addColumn(i18n("Source Mimetype"));
  _sourceList->setRootIsDecorated(true);
  QStringList primary = MimeType::all(false).primaryTypes();
  for (uint i=0; i<primary.count(); i++) {
    KListViewItem *item = 0;
    QStringList secondary = MimeType::all(false).secondaryTypes(primary[i]);
    for (uint j=0; j<secondary.count(); j++) {
      MimeType source(primary[i], secondary[j]);
      if ( Filter::isSupported(source, Source) ) {
        if ( item==0 ) {
          item = new KListViewItem(_sourceList, primary[i]);
          item->setOpen(true);
        }
        (void)new KListViewItem(item, secondary[j]);
      }
    }
  }
  connect(_sourceList, SIGNAL(selectionChanged()), SLOT(selectionChanged()));
  grid->addWidget(_sourceList, 1, 0);

  _destList = new KListView(plainPage());
  _destList->addColumn(i18n("Destination Mimetype"));
  _destList->addColumn(i18n("Filter name"));
  _destList->setResizeMode(QListView::LastColumn);
  _destList->setRootIsDecorated(true);
  _destList->setSelectionMode(QListView::NoSelection);
  grid->addWidget(_destList, 1, 1);
}

void MimetypesDialog::selectionChanged()
{
  _destList->clear();
  QListViewItem *item = _sourceList->currentItem();
  if ( item==0 || item->parent()==0 ) return;
  MimeType source(item->parent()->text(0), item->text(0));

  for (uint i=0; i<Nb_FileTypes; i++) {
    if ( FILE_TYPE_DATA[i].name==0
       || !Filter::isSupported(source, FileType(i)) ) continue;
    KListViewItem *type =
      new KListViewItem(_destList, i18n(FILE_TYPE_DATA[i].label));
    type->setOpen(true);
    for (uint j=0; j<Nb_Actions; j++) {
      Filter *f = Filter::find(source, FileType(i), Action(j), MimeType::null);
      if ( f==0 ) continue;
      KListViewItem *action =
        new KListViewItem(type, i18n(ACTION_DATA[j].label));
      action->setOpen(true);
      if ( !ACTION_DATA[j].needMimetype ) {
        action->setText(1, f->name());
        continue;
      }
      const BasicMimeTypeList &all = MimeType::all(true);
      BasicMimeTypeList::const_iterator it = all.begin();
      for (; it!=all.end(); ++it) {
        f = Filter::find(source, FileType(i), Action(j), it.key());
        if (f) (void)new KListViewItem(action, it.key().name(), f->name());
      }
    }
  }
}

//-----------------------------------------------------------------------------
FiltersDialog::FiltersDialog(QWidget *parent)
  : KDialogBase(Plain, i18n("Installed Filters"), Close, Close,
                parent, "filters_dialog", false)
{
  QGridLayout *grid = new QGridLayout(plainPage(), 1, 2);

  _filters = new KListView(plainPage());
  _filters->addColumn(i18n("Filter"));
  _filters->setRootIsDecorated(true);
  for (uint i=0; i<Nb_FileTypes; i++) {
    if ( FILE_TYPE_DATA[i].name==0
       || !Filter::isSupported(MimeType::null, FileType(i)) ) continue;
    KListViewItem *type = new KListViewItem(_filters, i18n(FILE_TYPE_DATA[i].label));
    type->setOpen(true);
    for (uint j=0; j<Nb_Actions; j++) {
      if ( !Filter::isSupported(MimeType::null, FileType(i), Action(j)) ) continue;
      KListViewItem *action = new KListViewItem(type, i18n(ACTION_DATA[j].label));
      action->setOpen(true);
      QPtrListIterator<Filter> it(*Filter::_list);
      while ( it.current() ) {
        if ( it.current()->type()==FileType(i)
             && it.current()->action()==Action(j) )
        (void)new KListViewItem(action, it.current()->name());
      ++it;
      }
    }
  }
  connect(_filters, SIGNAL(selectionChanged()), SLOT(selectionChanged()));
  grid->addWidget(_filters, 1, 0);

  _details = new KListView(plainPage());
  _details->addColumn(i18n("Mimetype"));
  _details->setResizeMode(QListView::LastColumn);
  _details->setRootIsDecorated(true);
  _details->setSelectionMode(QListView::NoSelection);
  grid->addWidget(_details, 1, 1);
}

void FiltersDialog::selectionChanged()
{
  _details->clear();
  QListViewItem *item = _filters->currentItem();
  if ( item==0 || item->parent()==0 || item->parent()->parent()==0 ) return;

  // find filter
  Filter *filter = 0;
  QString name = item->text(0);
  QPtrListIterator<Filter> it(*Filter::_list);
  while ( it.current() ) {
    if ( it.current()->name()==name ) {
      filter = it.current();
      break;
    }
    ++it;
  }

  // mimetypes
  for (uint i=0; i<Nb_IOTypes; i++) {
    IOType type = IOType(i);
    if ( type==Destination ) qDebug("action=%i %i", filter->action(),
    ACTION_DATA[filter->action()].needMimetype);
    if ( type==Destination && !ACTION_DATA[filter->action()].needMimetype )
      continue;
    qDebug("ok");
    KListViewItem *root = new KListViewItem(_details,
                   type==Source ? i18n("Sources") : i18n("Destinations"));
    root->setOpen(true);
    const BasicMimeTypeList &mlist = filter->supportedMimetypes(IOType(i));
    BasicMimeTypeList::const_iterator it = mlist.begin();
    for (; it!=mlist.end(); ++it)
      (void)new KListViewItem(root, it.key().name());
  }
}

#include "filter_dialogs.moc"
