/***************************************************************************
 *   Copyright (C) 2004 by Nicolas Hadacek                                 *
 *   hadacek@kde.org                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KONVERT_H_
#define _KONVERT_H_

#include <qmap.h>
#include <qradiobutton.h>
#include <qcheckbox.h>

#include <kmainwindow.h>
#include <kurlrequester.h>
#include <kdialogbase.h>

#include "listviews.h"

class QPushButton;
class QLabel;
class QWidgetStack;
class KProgress;
class KComboBox;

namespace Konvert
{
//----------------------------------------------------------------------------
class AddDirectoryDialog : public KDialogBase
{
  Q_OBJECT
public:
  AddDirectoryDialog(QWidget *parent);
  
  KURL::List getURLs(const KURL &directory);
  
private:
  QCheckBox    *_recurse;
  KComboBox    *_mimeFilter;
  QLineEdit    *_nameFilter;

  enum Type { AllFiles = 0, Directories, Nb_Types };
  static const char *LABELS[Nb_Types];
    
  Type type() const;
  FileType fileType() const;
};

//----------------------------------------------------------------------------
class MainWindow : public KMainWindow
{
  Q_OBJECT
public:
  MainWindow();
  MainWindow(const QString &type, const QString &action, const QString &options,
             const KURL &destination, const KURL &source, QString &error);
  ~MainWindow();

private slots:
  void addFiles();
  void addDirectory();
  void addFilesDir();
  void clearList();
  void clearSuccess();
  void showFilters();
  void showMimetypes();
  void start();
  void abort();
  void typeChanged();
  void actionChanged();
  void initAll();
  void updateStartButton();
  void process();

private:
  TodoListView  *_todo;
  QPushButton   *_add, *_clearList, *_clearSuccess;
  QPushButton   *_start, *_abort, *_chooseDestDir;
  KProgress     *_totalProgress;
  KURLRequester *_destDir;
  KComboBox     *_typeCombo, *_actionCombo;
  QWidgetStack  *_stack;
  KDialogBase   *_filtersDialog, *_mimetypesDialog;
  AddDirectoryDialog *_addDirDialog;

  bool       _success;
  Converter *_converter;
  uint       _step;
  TodoListViewItem *_current;
  class Data {
  public:
    Data() : initDone(false), filter(0) {}
    bool initDone;
    Filter *filter;
  };
  MimeTypeList<Data> _sourceMimetypes;
  enum State { Init = 0, Convert, CopyDest, Done, Nb_States,
               Stopped = Nb_States};
  State _state;

  FileType type() const;
  Action action() const;
  KURL destDir() const { return _destDir->url(); }
  MimeType destMimetype() const;
  FilterWidget *widget() const;
  void init(TodoListViewItem *);
  void setState(State state, bool process);
  void nextStep();
  bool queryClose();
  bool queryExit();
  void addItems(const KURL::List &urls);
  void addItem(const KURL &url);
  void stop();
  bool isRunning() const { return _state!=Stopped; }
};

} // namespace

#endif // _KONVERT_H_
