/***************************************************************************
 *   Copyright (C) 2004 by Nicolas Hadacek                                 *
 *   hadacek@kde.org                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "listviews.h"

#include <qlayout.h>
#include <qpopupmenu.h>
#include <qfile.h>
#include <qdir.h>
#include <qfileinfo.h>
#include <qlabel.h>
#include <qprogressbar.h>
#include <qstyle.h>
#include <qapplication.h>

#include <klocale.h>
#include <ktempfile.h>
#include <ktempdir.h>
#include <kiconloader.h>
#include <kfileitem.h>
#include <kio/netaccess.h>
#include <kapplication.h>
//#include <kfilemetainfo.h>

//#include "kfilemetainfowidget.h"

using namespace Konvert;

//-----------------------------------------------------------------------------
/*
MetaInfoDialog::MetaInfoDialog(QWidget *parent)
  : KDialogBase(Plain, i18n("Meta Informations"), Close, Close,
                parent, "meta_info_dialog", false), _top(0)
{
  _labels.setAutoDelete(true);
  _items.setAutoDelete(true);
}

void MetaInfoDialog::set(const KFileMetaInfo *info)
{
  delete _top;
  _top = 0;
  if ( info==0 ) return;

  _top = new QGridLayout(plainPage(), 2, 1, 10, 10);

  QStringList keys = info->supportedKeys();
  QStringList::const_iterator it = keys.begin();
  uint i = 0;
  for (; it!=keys.end(); ++it) {
    QLabel *label = new QLabel(*it, plainPage());
    _labels.append(label);
    _top->addWidget(label, i, 0);
    KFileMetaInfoWidget *mw =
      new KFileMetaInfoWidget(info->item(*it), 0, plainPage());
    _items.append(mw);
    _top->addWidget(mw, i, 1);
    i++;
  }
}
*/
//-----------------------------------------------------------------------------
const TodoListView::Data TodoListView::COLUMN_DATA[Nb_Columns] = {
  {I18N_NOOP("Source"), AlignAuto}, {I18N_NOOP("Type"), AlignAuto},
  {0, AlignAuto}, {I18N_NOOP("Destination"), AlignAuto},
  {I18N_NOOP("Type"), AlignAuto}, {0, AlignAuto},
  {I18N_NOOP("Lossy"), AlignHCenter}, {I18N_NOOP("Message"), AlignAuto}
};

TodoListView::TodoListView(QWidget *parent)
  : KListView(parent), _popupItem(0)//, _metaInfoDialog(0)
{
  setSelectionMode(QListView::Extended);
  for (uint i=0; i<Nb_Columns; i++) {
    addColumn(COLUMN_DATA[i].label==0 ? QString::null : i18n(COLUMN_DATA[i].label));
    setColumnAlignment(i, COLUMN_DATA[i].alignment);
  }
  setResizeMode(QListView::LastColumn);
  setShowSortIndicator(true);

  // context menu
  connect(this, SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)),
          SLOT(showContextMenu(QListViewItem *, const QPoint &, int)));
  _popup = new QPopupMenu(this);
  _popup->insertItem(SmallIconSet("remove"), i18n("Remove"),
                     this, SLOT(removeItem()));
  _popup->insertItem(SmallIconSet("run"), i18n("View"),
                     this, SLOT(viewItem()));
  //  _popup->insertItem(SmallIconSet("messagebox_info"), i18n("Properties"),
  //                     this, SLOT(viewItemProperties()));
}

void TodoListView::keyPressEvent(QKeyEvent *e)
{
  if ( e->key()==Key_Delete ) {
    QValueList<QListViewItem *> list;
    QListViewItemIterator it(this, QListViewItemIterator::Selected);
    while ( it.current() ) {
      list.append(it.current());
      ++it;
    }
    QValueList<QListViewItem *>::const_iterator itl = list.begin();
    for (; itl!=list.end(); ++itl)
      delete *itl;
    emit changed();
  }
  e->ignore();
}

TodoListViewItem *TodoListView::addItem(const KURL &url)
{
  if ( _urls.contains(url) ) return 0;
  FileItem fitem(url);
  TodoListViewItem *item = new TodoListViewItem(fitem, this);
  _urls.append(url);
  emit changed();
  return item;
}

void TodoListView::removeItem(TodoListViewItem *item)
{
  qDebug("remove url %s", item->source().url().url().latin1());
  _urls.remove(item->source().url());
  delete item;
  emit changed();
}

void TodoListView::clear()
{
  _urls.clear();
  KListView::clear();
  emit changed();
}


void TodoListView::showContextMenu(QListViewItem *, const QPoint &pos, int)
{
  _popupItem =
    static_cast<TodoListViewItem *>(itemAt(viewport()->mapFromGlobal(pos)));
  if ( _popupItem==0 ) return;
  _popup->exec(pos);
}

void TodoListView::viewItem()
{
  if ( _popupItem==0 ) return;
  KFileItem *item =
    static_cast<TodoListViewItem *>(_popupItem)->source().item();
  item->run();
  delete item;
}
/*
void TodoListView::viewItemProperties()
{
  if ( _popupItem==0 ) return;
  KFileItem *item =
    static_cast<TodoListViewItem *>(_popupItem)->item(Source).item();
  if ( _metaInfoDialog==0 )
    _metaInfoDialog = new MetaInfoDialog(this);
  _metaInfoDialog->set(&item->metaInfo());
  _metaInfoDialog->show();
  delete item;
}
*/
//-----------------------------------------------------------------------------
const char *TodoListViewItem::COLORS[Nb_States] = {
  "#000000", "#B47B00", "#B40000", "#2DB400"
};

TodoListViewItem::TodoListViewItem(const FileItem &source, KListView *list)
  : KListViewItem(list), _source(source), _state(Normal), _progress(0)
{
  setText(TodoListView::Source, source.name());
  setPixmap(TodoListView::Source, source.pixmap());
  setText(TodoListView::SourceMimetype, source.mimetype().name());
}

TodoListViewItem::~TodoListViewItem()
{
  delete _progress;
}

void TodoListViewItem::setState(State state)
{
  _state = state;
  QPixmap pixmap;
  switch (state) {
    case Normal: break;
    case NoFilter: pixmap = SmallIcon("messagebox_warning", kapp); break;
    case Error: pixmap = SmallIcon("messagebox_critical", kapp); break;
    case Success: pixmap = SmallIcon("ok", kapp); break;
    case Nb_States: break;
  }
  setPixmap(TodoListView::Message, pixmap);
}

void TodoListViewItem::setDataLoss(bool dataLoss)
{
  QPixmap pixmap;
  if (dataLoss) pixmap = SmallIcon("messagebox_warning", kapp);
  setPixmap(TodoListView::DataLoss, pixmap);
}

void TodoListViewItem::setProgress(uint p)
{
  if ( _progress==0 ) {
    _progress = new QProgressBar(100, listView());
    _progress->hide();
  }
  _progress->setProgress(p);
  listView()->triggerUpdate();
}

void TodoListViewItem::paintCell(QPainter *p, const QColorGroup &cg,
                                 int column, int width, int alignment)
{
  if ( column!=TodoListView::Message
       || _progress==0 || _progress->progress()==0 ) {
    QColorGroup ncg = cg;
    QColorGroup::ColorRole cr =
      (listView()->viewport()->backgroundMode()==Qt::FixedColor
       ? QColorGroup::Background : QColorGroup::Base);
    QColor cb = (isAlternate()
                 ? static_cast< KListView* >(listView())->alternateBackground()
                 : cg.color(cr));
    ncg.setColor(cr, cb);
    ncg.setColor(QColorGroup::Text, COLORS[_state]);
    QListViewItem::paintCell(p, ncg, column, width, alignment);
  } else {
    _progress->resize(width, height());
    QColorGroup ncg = _progress->colorGroup();
    QRect rect(0, 0, width-1, height()-1);
    QApplication::style().drawControl(QStyle::CE_ProgressBarGroove, p,
                         _progress, rect, ncg, QStyle::Style_Enabled);
    QApplication::style().drawControl(QStyle::CE_ProgressBarContents, p,
                                      _progress, rect, ncg);
    QApplication::style().drawControl(QStyle::CE_ProgressBarLabel, p,
                                      _progress, rect, ncg);
  }
}

#include "listviews.moc"
