/***************************************************************************
 *   Copyright (C) 2004 by Nicolas Hadacek                                 *
 *   hadacek@kde.org                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _LISTVIEWS_H_
#define _LISTVIEWS_H_

#include <kurl.h>
#include <klistview.h>
//#include <kdialogbase.h>

#include "mimetype.h"
#include "filter.h"
#include "converter.h"

class QProgressBar;
class QGridLayout;
class QPopupMenu;
class KTempFile;
class KTempDir;
class KDialogBase;
class KFileItem;
//class KFileMetaInfo;

namespace Konvert
{
class TodoListViewItem;

//-----------------------------------------------------------------------------
/*
class MetaInfoDialog : public KDialogBase
{
  Q_OBJECT
public:
  MetaInfoDialog(QWidget *parent);

  void set(const KFileMetaInfo *info);

private:
  QGridLayout      *_top;
  QPtrList<QLabel>  _labels;
  QPtrList<QWidget> _items;
};
*/
//-----------------------------------------------------------------------------
class TodoListView : public KListView
{
  Q_OBJECT
public:
  enum Columns { Source = 0, SourceMimetype, Empty1,
                 Destination, DestMimetype, Empty2,
                 DataLoss, Message, Nb_Columns };
  struct Data {
    const char *label;
    int alignment;
  };
  static const Data COLUMN_DATA[Nb_Columns];

public:
  TodoListView(QWidget *parent);

  TodoListViewItem *addItem(const KURL &url);
  void removeItem(TodoListViewItem *item);

public slots:
  void clear();

signals:
  void changed();

protected:
  void keyPressEvent(QKeyEvent *e);

private slots:
  void showContextMenu(QListViewItem *item, const QPoint &pos, int col);
  void removeItem() { removeItem(_popupItem); }
  void viewItem();
  //  void viewItemProperties();

private:
  QPopupMenu       *_popup;
  TodoListViewItem *_popupItem;
  QValueList<KURL>  _urls;
  //  MetaInfoDialog *_metaInfoDialog;
};

//-----------------------------------------------------------------------------
class TodoListViewItem : public KListViewItem
{
public:
  enum State { Normal = 0, NoFilter, Error, Success, Nb_States };
  static const char *COLORS[Nb_States];

public:
  TodoListViewItem(const FileItem &source, KListView *list);
  ~TodoListViewItem();

  void setState(State state);
  State state() const { return _state; }
  void setProgress(uint progress); // between 0 and 100
  void setDataLoss(bool dataLoss);
  const FileItem &source() const { return _source; }

private:
  const FileItem _source;
  State          _state;
  QProgressBar  *_progress;

  virtual void paintCell(QPainter *, const QColorGroup &, int column,
                         int width, int alignment);
};

} // namespace

#endif // _KONVERT_H_
