#include "mimetype.h"

using namespace Konvert;

const MimeType::AllData MimeType::DATA[] = {

// application
  { "application/andrew-inset",  UnspecifiedData },
  { "application/cab",           { Archive,     None, "application/cab", 0, 0 }},
  { "application/chm",           UnspecifiedData },
  { "application/futuresplash",  UnspecifiedData },
  { "application/illustrator",   { Image,       None, 0, 0, 0 }},
  { "application/mathml+xml",    { Equation,    None, 0, 0, 0 }},
  { "application/msexcel",       { Spreadsheet, None, 0, 0, 0 }},
  { "application/mspowerpoint",  { Document,    None, 0, 0, 0 }},
  { "application/ms-tnef",       { Archive,     None, "application/ms-tnef", 0, 0 }},
  { "application/msword",        { Document,    None, 0, 0, 0 }},
  { "application/octet-stream",  UnspecifiedData },
  { "application/oda",           UnspecifiedData },
  { "application/ogg",           { Alias,       None, 0, "application/x-ogg", 0 }},
  { "application/origin",        { Spreadsheet, None, 0, 0, 0 }},
  { "application/pdf",           { Publishing,    None, 0, 0, 0 }},
  { "application/pgp",           UnspecifiedData },
  { "application/pgp-encrypted", UnspecifiedData },
  { "application/pgp-keys",      UnspecifiedData },
  { "application/pgp-signature", UnspecifiedData },
  { "application/pkcs10",        UnspecifiedData },
  { "application/pkcs7-mime",            UnspecifiedData },
  { "application/pkcs7-signature",       UnspecifiedData },
  { "application/postscript",            { Publishing, None, 0, 0, 0 }},
  { "application/qif",                   { Finance,  None, 0, 0, 0 }},
  { "application/rtf",                   { Document, None, 0, 0, 0 }},
  { "application/sdp",                   UnspecifiedData },
  { "application/sieve",                 UnspecifiedData },
  { "application/smil",                  { Alias,    None, 0, "application/x-smil", 0 }},
  { "application/vnd.mozilla.xul+xml",   UnspecifiedData },
  { "application/vnd.ms-asf",            { Alias,    None, 0, "video/x-ms-asf", 0 }},
  { "application/vnd.ms-excel",          { Alias,    None, 0, "application/msexcel", 0 }},
  { "application/vnd.ms-word",           { Alias,    None, 0, "application/msword", 0 }},
  { "application/vnd.palm",              UnspecifiedData },
  { "application/vnd.rn-realmedia",      UnspecifiedData },
  { "application/vnd.stardivision.calc",    { Spreadsheet, None, 0, 0, 0 }},
  { "application/vnd.stardivision.chart",   { Graph,       None, 0, 0, 0 }},
  { "application/vnd.stardivision.draw",    { Image,       Vectorial, 0, 0, 0 }},
  { "application/vnd.stardivision.impress", { Document,    None, 0, 0, 0 }},
  { "application/vnd.stardivision.math",    { Equation,    None, 0, 0, 0 }},
  { "application/vnd.stardivision.writer",  { Document,    None, 0, 0, 0 }},
  { "application/vnd.stardivision.writer-global", UnspecifiedData },
  { "application/vnd.sun.xml.calc",               { Spreadsheet, None,      0, 0, 0 }},
  { "application/vnd.sun.xml.calc.template",      { Spreadsheet, Template,  0, 0, 0 }},
  { "application/vnd.sun.xml.draw",               { Image,       Vectorial, 0, 0, 0 }},
  { "application/vnd.sun.xml.draw.template",      { Image,       Template | Vectorial, 0, 0, 0 }},
  { "application/vnd.sun.xml.impress",            { Document,    None,      0, 0, 0 }},
  { "application/vnd.sun.xml.impress.template",   { Document,    Template,  0, 0, 0 }},
  { "application/vnd.sun.xml.writer",             { Document,    None,      0, 0, 0 }},
  { "application/vnd.sun.xml.writer.global",      UnspecifiedData },
  { "application/vnd.sun.xml.writer.math",        { Equation,    None,      0, 0, 0 }},
  { "application/vnd.sun.xml.writer.template",    { Document,    Template,  0, 0, 0 }},
  { "application/wordperfect",      { Document,    None,      0, 0, 0 }},
  { "application/x-abiword",        { Document,    None,      0, 0, 0 }},
  { "application/x-ace",            { Archive,     None, "application/x-ace", 0, 0 }},
  { "application/x-afm",            UnspecifiedData },
  { "application/x-amipro",         { Document,    None,      0, 0, 0 }},
  { "application/x-applixgraphics", { Image,       Vectorial, 0, 0, 0 }},
  { "application/x-applixspread",   { Spreadsheet, None,      0, 0, 0 }},
  { "application/x-applixword",     { Document,    None,      0, 0, 0 }},
  { "application/x-applix-spreadsheet",           { Alias,       None,      0, "application/x-applixspread", 0 }},
  { "application/x-applix-word",    { Alias,       None,      0, "application/x-applixword", 0 }},
  { "application/x-arc",         { Archive,    None, "application/x-arc", 0, 0 }},
  { "application/x-archive",     { Archive,    None, "application/x-archive", 0, 0 }},
  { "application/x-arj",         { Archive,    None, "application/x-arj", 0, 0 }},
  { "application/x-artsbuilder", UnspecifiedData },
  { "application/x-asp",         UnspecifiedData },
  { "application/x-awk",         { Code,       None, 0, 0, 0 }},
  { "application/x-backup",      { Alias,      None, 0, "application/x-trash", 0 }},
  { "application/x-bcpio",       { Archive,    None, "application/x-cpio", 0, 0 }},
  { "application/x-bittorrent",  UnspecifiedData },
  { "application/x-bz2dvi",      { Compressed, None, "application/x-dvi", "application/x-bzip2", 0 }},
  { "application/x-bzip",        { Compressed, None, 0, "application/x-bzip2", 0 }},
  { "application/x-bzip2",       { Compressed, None, 0, "application/x-bzip2", 0 }},
  { "application/x-bzip-compressed-tar", { Alias, None, 0, "application/x-tbz", 0 }},
  { "application/x-cda",         { Audio,      None, 0, 0, 0 }},
  { "application/x-cgi",         UnspecifiedData },
  { "application/x-chess-pgn",   UnspecifiedData },
  { "application/x-class-file",  UnspecifiedData },
  { "application/x-compress",    { Compressed, None, 0, "application/x-gzip", 0 }},
  { "application/x-compressed-tar", { Alias, None, 0, "application/x-tgz", 0 }},
  { "application/x-core",        UnspecifiedData },
  { "application/x-core-file",   { Alias,      None, 0, "application/x-core", 0 }},
  { "application/x-cpio",        { Archive,    None, "application/x-cpio", 0, 0 }},
  { "application/x-cpio-compressed", { Archive, None, "application/x-cpio", "application/x-gzip", 0 }},
  { "application/x-crossover-exe",   UnspecifiedData },
  { "application/x-cue",         UnspecifiedData },
  { "application/x-dbase",       { Database,  None, 0, 0, 0 }},
  { "application/x-deb",         { Package,   None, 0, 0, 0 }},
  { "application/x-debian-package", { Alias, None, 0, "application/x-deb", 0 }},
  { "application/x-designer",    UnspecifiedData },
  { "application/x-desktop",     UnspecifiedData },
  { "application/x-dia-diagram", UnspecifiedData },
  { "application/x-dvi",         { Publishing,  None, 0, 0, 0 }},
  { "application/x-edu",         UnspecifiedData },
  { "application/x-edugallery",  UnspecifiedData },
  { "application/x-e-theme",     UnspecifiedData },
  { "application/x-executable",  UnspecifiedData },
  { "application/x-font-afm",         { Font, None, 0, 0, 0 }},
  { "application/x-font-bdf",         { Font, None, 0, 0, 0 }},
  { "application/x-font-ghostscript", { Font, None, 0, 0, 0 }},
  { "application/x-font-linux-psf",   { Font, None, 0, 0, 0 }},
  { "application/x-font-otf",         { Font, None, 0, 0, 0 }},
  { "application/x-font-pcf",         { Font, None, 0, 0, 0 }},
  { "application/x-font-snf",         { Font, None, 0, 0, 0 }},
  { "application/x-font-speedo",      { Font, None, 0, 0, 0 }},
  { "application/x-font-ttc",         { Font, None, 0, 0, 0 }},
  { "application/x-font-ttf",         { Font, None, 0, 0, 0 }},
  { "application/x-font-type1",       { Font, None, 0, 0, 0 }},
  { "application/x-gettext",    UnspecifiedData },
  { "application/x-glade",      UnspecifiedData },
  { "application/x-gnucash",    { Finance, None, 0, 0, 0 }},
  { "application/x-gnumeric",   { Spreadsheet, None, 0, 0, 0 }},
  { "application/x-graphite",   { Graph, None, 0, 0, 0 }},
  { "application/x-gtar",       { Alias, None, 0, "application/x-tar", 0 }},
  { "application/x-gzdvi",      { Compressed, None, "application/x-dvi", "application/x-gzip", 0 }},
  { "application/x-gzip",       { Compressed, None, 0, "application/x-gzip", 0 }},
  { "application/x-gzpostscript", { Compressed, None, "application/postscript", "application/x-gzip", 0 }},
  { "application/x-hancomword",   { Document, None, 0, 0, 0 }},
  { "application/x-hdf",     UnspecifiedData },
  { "application/xhtml+xml", UnspecifiedData },
  { "application/x-iso",     { Archive, None, "application/x-iso", 0, 0 }},
  { "application/x-jar",     { Archive, None, "application/x-jar", 0, 0 }},
  { "application/x-java",    UnspecifiedData },
  { "application/x-java-applet", UnspecifiedData },
  { "application/x-java-byte-code", { Alias, None, 0, "application/x-java", 0 }},
  { "application/x-javascript",  { Code, None, 0, 0, 0 }},
  { "application/x-jbuilder-project", UnspecifiedData },
  { "application/x-k3b",         UnspecifiedData },
  { "application/x-karbon",      { Image, None, 0, 0, 0 }},
  { "application/x-kcachegrind", UnspecifiedData },
  { "application/x-kchart",      { Graph, None, 0, 0, 0 }},
  { "application/x-kcsrc",       UnspecifiedData },
  { "application/x-kde-app-info",     UnspecifiedData },
  { "application/x-kdevelop",         UnspecifiedData },
  { "application/x-kdevelop-project", UnspecifiedData },
  { "application/x-kde-wallet",       UnspecifiedData },
  { "application/x-kformula",         { Equation, None, 0, 0, 0 }},
  { "application/x-kgeo",     UnspecifiedData },
  { "application/x-kgetlist", UnspecifiedData },
  { "application/x-kig",      UnspecifiedData },
  { "application/x-kivio",    UnspecifiedData },
  { "application/x-kolf",     UnspecifiedData },
  { "application/x-konsole",  UnspecifiedData },
  { "application/x-kontour",  { Image, None, 0, 0, 0 }},
  { "application/x-kourse",   UnspecifiedData },
  { "application/x-kpovmodeler", UnspecifiedData },
  { "application/x-kpresenter",  { Document, None, 0, 0, 0 }},
  { "application/x-krita",   UnspecifiedData },
  { "application/x-kseg",    UnspecifiedData },
  { "application/x-kspread", { Spreadsheet, None, 0, 0, 0 }},
  { "application/x-kspread-crypt", { Alias, None, 0, "application/x-kspread", 0 }},
  { "application/x-ksysguard", UnspecifiedData },
  { "application/x-ksysv-package", UnspecifiedData },
  { "application/x-kudesigner",    { Unspecified, Template, 0, 0, 0 }},
  { "application/x-kugar",    UnspecifiedData },
  { "application/x-kword",    { Document, None, 0, 0, 0 }},
  { "application/x-kword-crypt", { Alias, None, 0, "application/x-kword", 0 }},
  { "application/x-lha",      { Archive, None, "application/x-lha", 0, 0 }},
  { "application/x-lhz",      { Alias, None, 0, "application/x-lha", 0 }},
  { "application/x-linguist", UnspecifiedData },
  { "application/x-lyx",      { Document, None, 0, 0, 0 }},
  { "application/x-lzop",     { Compressed, None, 0, "application/x-lzop", 0 }},
  { "application/x-magicpoint", { Document, None, 0, 0, 0 }},
  { "application/x-mif",        { Document, None, 0, 0, 0 }},
  { "application/x-msaccess",   UnspecifiedData },
  { "application/x-msdos-program", UnspecifiedData },
  { "application/x-mswrite",       { Document, None, 0, 0, 0 }},
  { "application/x-netcdf",        UnspecifiedData },
  { "application/x-object",        UnspecifiedData },
  { "application/x-object-file",   { Alias, None, 0, "application/x-object", 0 }},
  { "application/x-ogg",  UnspecifiedData },
  { "application/x-oleo", { Spreadsheet, None, 0, 0, 0 }},
  { "application/x-perl", { Code, None, 0, 0, 0 }},
  { "application/x-perl-module", UnspecifiedData },
  { "application/x-php",     { Code, None, 0, 0, 0 }},
  { "application/x-pkcs12",  UnspecifiedData },
  { "application/x-profile", UnspecifiedData },
  { "application/x-python",  { Code, None, 0, 0, 0 }},
  { "application/x-python-bytecode", UnspecifiedData },
  { "application/x-quattropro",      { Spreadsheet, None, 0, 0, 0 }},
  { "application/x-qw",     { Finance, None, 0, 0, 0 }},
  { "application/x-rar",    { Archive, None, "application/x-rar", 0, 0 }},
  { "application/x-rar-compressed", { Alias, None, 0, "application/x-rar", 0 }},
  { "application/x-reject", UnspecifiedData },
  { "application/x-rpm",    { Package, None, 0, 0, 0 }},
  { "application/x-ruby",   { Code, None, 0, 0, 0 }},
  { "application/x-sdp",    UnspecifiedData },
  { "application/x-shar",   { Archive, None, "application/x-shar", 0, 0 }},
  { "application/x-sharedlib", UnspecifiedData },
  { "application/x-shared-library", { Alias, None, 0, "application/x-sharedlib", 0 }},
  { "application/x-shared-library-la", UnspecifiedData },
  { "application/x-shellscript",       { Code, None, 0, 0, 0 }},
  { "application/x-shockwave-flash",   UnspecifiedData },
  { "application/x-shockwave-flash2-preview", { Alias, None, 0, "image/vnd.rn-realflash", 0 }},
  { "application/x-smb-workgroup",     { Alias, None, 0, "inode/directory", 0 }},
  { "application/x-smil",    { Code, None, 0, 0, 0 }},
  { "application/x-staroffice-presentation", { Alias, None, 0, "application/vnd.stardivision.impress", 0 }},
  { "application/x-staroffice-spreadsheet", { Alias, None, 0, "application/vnd.stardivision.calc", 0 }},
  { "application/x-staroffice-words",  { Alias, None, 0, "application/vnd.stardivision.writer", 0 }},
  { "application/x-sv4cpio",   { Archive, None, "application/x-cpio", 0, 0 }},
  { "application/x-sv4crc",    { Archive, None, "application/x-cpio", 0, 0 }},
  { "application/x-tar",       { Archive, None, "application/x-tar", 0, 0 }},
  { "application/x-tarz",      { Archive, None, "application/x-tar", "application/x-gzip", 0 }},
  { "application/x-tbz",       { Archive, None, "application/x-tar", "application/x-bzip2", 0 }},
  { "application/x-tex-gf",    UnspecifiedData },
  { "application/x-tex-pk",    UnspecifiedData },
  { "application/x-tgif",      UnspecifiedData },
  { "application/x-tgz",       { Archive, None, "application/x-tar", "application/x-gzip", 0 }},
  { "application/x-theme",     UnspecifiedData },
  { "application/x-trash",     UnspecifiedData },
  { "application/x-troff",     { Document, None, 0, 0, 0 }},
  { "application/x-troff-man", { Document, None, 0, 0, 0 }},
  { "application/x-troff-man-compressed", { Compressed, None, "application/x-troff-man", "application/x-gzip", 0 }},
  { "application/x-tuberling",    UnspecifiedData },
  { "application/x-tzo",          { Archive, None, "application/x-tar", "application/x-lzop", 0 }},
  { "application/x-uml",          UnspecifiedData },
  { "application/x-unix-archive", { Alias, None, 0, "application/x-archive", 0 }},
  { "application/x-urpmi",        UnspecifiedData },
  { "application/x-urpmi-media",  UnspecifiedData },
  { "application/x-ustar",        { Archive, None, "application/x-cpio", 0, 0 }},
  { "application/x-vnd.kde.kexi", UnspecifiedData },
  { "application/x-vnd.kde.kplato", UnspecifiedData },
  { "application/x-vnd.kde.kugar.mixed", UnspecifiedData },
  { "application/x-webarchive",          { Archive, None, "application/x-webarchive", 0, 0 }},
  { "application/x-wais-source",         UnspecifiedData },
  { "application/x-x509-ca-cert",        UnspecifiedData },
  { "application/x-xbase",    { Alias, None, 0, "application/x-dbase", 0 }},
  { "application/x-zerosize", { Unspecified, None, 0, 0, 0 }},
  { "application/x-zip",      { Archive, None, "application/x-zip", 0, 0 }},
  { "application/x-zoo",      { Archive, None, "application/x-zoo", 0, 0 }},
  { "application/zip",        { Alias, None, 0, "application/x-zip", 0 }},

// audio
  { "audio/aac",        { Audio, Lossy,  0, 0, 0 }},
  { "audio/ac3",        { Audio, None,   0, 0, 0 }},
  { "audio/aiff",       { Alias, None,   0, "audio/x-aiff", 0 }},
  { "audio/basic",      { Alias, None,   0, "audio/x-ulaw", 0 }},
  { "audio/mp4",        { Audio, Lossy,  0, 0, 0 }},
  { "audio/vnd.rn-realaudio", { Alias, None, 0, "audio/x-real-audio", 0 }},
  { "audio/vorbis",     { Alias, None,   0, "audio/x-vorbis", 0 }},
  { "audio/wav",        { Alias, None,   0, "audio/x-wav", 0 }},
  { "audio/x-adpcm",    { Audio, None,   0, 0, 0 }},
  { "audio/x-aiff",     { Audio, None,   0, 0, 0 }}, // can contains multiple files... (including images ?)
  { "audio/x-flac",     { Audio, None,   0, 0, 0 }},
  { "audio/x-karaoke",  UnspecifiedData },
  { "audio/x-it",       { Audio,   None,   0, 0, 0 }},
  { "audio/x-matroska", { Audio,   None,   0, 0, 0 }},
  { "audio/x-midi",     { Audio,   Vectorial, 0, 0, 0 }},
  { "audio/x-mod",      { Audio,   None, 0, 0, 0 }},
  { "audio/x-mp3",      { Audio,   Lossy, 0, 0, 0 }},
  { "audio/x-mpegurl",  UnspecifiedData },
  { "audio/x-oggflac",  { Audio,   None, 0, 0, 0 }},
  { "audio/x-pn-aiff",  UnspecifiedData },
  { "audio/x-pn-au",    { Alias,   None, 0, "audio/x-ulaw", 0 }},
  { "audio/x-pn-realaudio-plugin", UnspecifiedData },
  { "audio/x-pn-realaudio",  UnspecifiedData },
  { "audio/x-pn-wav",        { Alias, None, 0, "audio/x-wav", 0 }},
  { "audio/x-pn-windows-acm", { Alias, None, 0, "audio/x-wav", 0 }},
  { "audio/x-real-audio", { Audio, Lossy, 0, 0, 0 }},
  { "audio/x-s3m",        { Audio, None, 0, 0, 0 }},
  { "audio/x-scpls",      { Audio, None, 0, 0, 0 }},
  { "audio/x-speex",      { Audio, None, 0, 0, 0 }},
  { "audio/x-stm",        { Audio, None, 0, 0, 0 }},
  { "audio/x-ulaw",       { Audio, None, 0, 0, 0 }},
  { "audio/x-voc",        { Audio, None, 0, 0, 0 }},
  { "audio/x-vorbis",     { Audio, Lossy, 0, 0, "ogg" }},
  { "audio/x-wav",        { Audio, None, 0, 0, 0 }},
  { "audio/x-xi",         { Audio, None, 0, 0, 0 }},
  { "audio/x-xm",         { Audio, None, 0, 0, 0 }},

// image
  { "image/cgm", { Image, None, 0, 0, 0 }},
  { "image/fax-g3", { Image, None, 0, 0, 0 }},
  { "image/gif", { Image, None, 0, 0, 0 }},
  { "image/ief", { Image, None, 0, 0, 0 }}, // same as AIFF ???
  { "image/jp2", { Image, Lossy, 0, 0, 0 }},
  { "image/jpeg", { Image, Lossy, 0, 0, 0 }},
  { "image/pjpeg", { Alias, None, 0, "image/jpeg", 0 }},
  { "image/png", { Image, None, 0, 0, 0 }},
  { "image/svg", { Alias, None, 0, "image/svg+xml", 0 }},
  { "image/svg+xml", { Image, Vectorial, 0, 0, 0 }},
  { "image/tiff", { Image, None, 0, 0, 0 }},
  { "image/vnd", UnspecifiedData }, // ???
  { "image/vnd.rn-realflash", { Image, None, 0, 0, 0 }},
  { "image/vnd.rn-realpix", { Image, None, 0, 0, 0 }},
  { "image/x-3ds", { Image, None, 0, 0, 0 }},
  { "image/x-applix-graphic", { Alias, None, 0, "application/x-applixgraphics", 0 }},
  { "image/x-bmp", { Image, None, 0, 0, 0 }},
  { "image/x-cmu-raster", { Image, None, 0, 0, 0 }},
  { "image/x-compressed-xcf", { Image, None, "image/x-xcf-gimp", "application/x-gzip", 0 }},
  { "image/x-eps",      { Image, Vectorial, 0, 0, 0 }},
  { "image/x-ico",      { Image, None, 0, 0, 0 }},
  { "image/x-iff",      { Image, None, 0, 0, 0 }},
  { "image/x-ilbm",     { Image, None, 0, 0, 0 }},
  { "image/x-jng",      { Image, Lossy, 0, 0, 0 }},
  { "image/x-lwo",      UnspecifiedData },
  { "image/x-lws",      UnspecifiedData },
  { "image/x-msod",     { Image, None, 0, 0, 0 }},
  { "image/x-pcx",      { Image, None, 0, 0, 0 }},
  { "image/x-photo-cd", { Image, None, 0, 0, 0 }},
  { "image/x-portable-anymap",  { Alias, None, 0, "image/x-portable-pixmap", 0 }},
  { "image/x-portable-bitmap",  { Image, None, 0, 0, 0 }},
  { "image/x-portable-graymap", { Alias, None, 0, "image/x-portable-greymap", 0 }},
  { "image/x-portable-greymap", { Image, None, 0, 0, 0 }},
  { "image/x-portable-pixmap",  { Image, None, 0, 0, 0 }},
  { "image/x-psd",   { Image, None, 0, 0, 0 }},
  { "image/x-rgb",   { Image, None, 0, 0, 0 }},
  { "image/x-targa", { Image, None, 0, 0, 0 }},
  { "image/x-tga",   { Image, None, 0, "image/x-targa", 0 }},
  { "image/x-vnd.adobe.photoshop", { Image, Vectorial, 0, 0, 0 }},
  { "image/x-vnd.trolltech.qpicture", { Image, Vectorial, 0, 0, 0 }},
  { "image/x-wmf", { Image, None, 0, 0, 0 }},
  { "image/x-xbitmap", { Alias, None, 0, "image/x-xbm", 0 }},
  { "image/x-xbm", { Image, None, 0, 0, 0 }},
  { "image/x-xcf", { Alias, None, 0, "image/x-xcf-gimp", 0 }},
  { "image/x-xcf-gimp", { Image, None, 0, 0, 0 }},
  { "image/x-xcursor", { Image, None, 0, 0, 0 }},
  { "image/x-xfig", { Image, Vectorial, 0, 0, 0 }},
  { "image/x-xpm", { Image, None, 0, 0, 0 }},
  { "image/x-xwindowdump", UnspecifiedData },

// inode
  { "inode/directory", { Directory, None, 0, 0, 0 }},

// interface
  { "interface/x-winamp-skin", UnspecifiedData },

// model
  { "model/vrml", UnspecifiedData },

// text
  { "text/abiword",  { Alias, None, 0, "application/x-abiword", 0 }},
  { "text/bib",      { Alias, None, 0, "text/x-bibtex", 0 }},
  { "text/calendar", UnspecifiedData },
  { "text/css",      UnspecifiedData },
  { "text/docbook",  { Document, None, 0, 0, 0 }},
  { "text/enriched", { Document, None, 0, 0, 0 }},
  { "text/html",     { Document, None, 0, 0, 0 }},
  { "text/mathml",   { Equation, None, 0, 0, 0 }},
  { "text/mrml",     UnspecifiedData },
  { "text/plain",    { Document, None, 0, 0, 0 }},
  { "text/rdf",      UnspecifiedData },
  { "text/richtext", { Document, None, 0, 0, 0 }},
  { "text/rss",      UnspecifiedData },
  { "text/rtf",      { Document, None, 0, 0, 0 }},
  { "text/sgml",     UnspecifiedData },
  { "text/spreadsheet", { Spreadsheet, None, 0, 0, 0 }},
  { "text/tab-separated-values", { Spreadsheet, None, 0, 0, 0 }},
  { "text/vnd.rn-realtext", UnspecifiedData },
  { "text/vnd.wap.wml", { Document, None, 0, 0, 0 }},
  { "text/x-adasrc",    { Code, None, 0, 0, 0 }},
  { "text/x-authors",   { Unspecified, None, 0, "text/plain", 0 }},
  { "text/x-bibtex",    { Document, None, 0, 0, 0 }},
  { "text/x-chdr",      { Code, None, 0, 0, 0 }},
  { "text/x-c++hdr",    { Code, None, 0, 0, 0 }},
  { "text/x-copying",   { Unspecified, None, 0, "text/plain", 0 }},
  { "text/x-credits",   { Unspecified, None, 0, "text/plain", 0 }},
  { "text/x-csh",       { Code, None, 0, 0, 0 }},
  { "text/x-csrc",      { Code, None, 0, 0, 0 }},
  { "text/x-c++src",    { Code, None, 0, 0, 0 }},
  { "text/x-csv",       { Spreadsheet, None, 0, 0, 0 }},
  { "text/x-dcl",       { Code, None, 0, 0, 0 }},
  { "text/x-diff",      UnspecifiedData },
  { "text/x-dsl",       UnspecifiedData },
  { "text/x-dtd",       UnspecifiedData },
  { "text/x-emacs-lisp", { Code, None, 0, 0, 0 }},
  { "text/x-fortran",    { Code, None, 0, 0, 0 }},
  { "text/x-gtkrc",      UnspecifiedData },
  { "text/x-idl",     { Code, None, 0, 0, 0 }},
  { "text/x-install", { Unspecified, None, 0, "text/plain", 0 }},
  { "text/x-java",   { Code, None, 0, 0, 0 }},
  { "text/x-katefilelist", UnspecifiedData },
  { "text/x-ksysv-log",    UnspecifiedData },
  { "text/x-latex",        { Document, None, 0, 0, 0 }},
  { "text/x-ldif",     UnspecifiedData },
  { "text/x-log",      UnspecifiedData },
  { "text/x-makefile", { Code, None, 0, 0, 0 }},
  { "text/x-moc",      { Code, None, 0, 0, 0 }},
  { "text/x-mswinurl", UnspecifiedData },
  { "text/x-objcsrc",  { Code, None, 0, 0, 0 }},
  { "text/x-pascal",   { Code, None, 0, 0, 0 }},
  { "text/x-readme",   { Unspecified, None, 0, "text/plain", 0 }},
  { "text/x-scheme",   { Code, None, 0, 0, 0 }},
  { "text/x-setext",   UnspecifiedData },
  { "text/x-sh",  { Code, None, 0, 0, 0 }},
  { "text/x-sql", { Code, None, 0, 0, 0 }},
  { "text/x-tcl", { Code, None, 0, 0, 0 }},
  { "text/x-tex", { Document, None, 0, 0, 0 }},
  { "text/x-texinfo",   UnspecifiedData },
  { "text/x-troff",     { Alias, None, 0, "application/x-troff", 0 }},
  { "text/x-troff-man", { Alias, None, 0, "application/x-troff-man", 0 }},
  { "text/x-troff-me",  UnspecifiedData },
  { "text/x-troff-mm",  UnspecifiedData },
  { "text/x-troff-ms",  UnspecifiedData },
  { "text/x-vcalendar", UnspecifiedData },
  { "text/x-vcard", UnspecifiedData },
  { "text/x-xslfo", UnspecifiedData },
  { "text/x-xslt",  UnspecifiedData },
  { "text/xmcd",    UnspecifiedData },
  { "text/xml",     UnspecifiedData },

// video
  { "video/mp4", { Video, None, 0, 0, 0 }},
  { "video/mpeg", { Video, None, 0, 0, 0 }},
  { "video/quicktime", { Video, None, 0, 0, 0 }},
  { "video/vnd.rn-realvideo", { Video, None, 0, 0, 0 }},
  { "video/x-anim", { Video, None, 0, 0, 0 }},
  { "video/x-flc", { Video, None, 0, 0, 0 }},
  { "video/x-fli", { Alias, None, 0, "video/x-flic", 0 }},
  { "video/x-flic", { Video, None, 0, 0, 0 }},
  { "video/x-matroska", { Video, None, 0, 0, 0 }},
  { "video/x-mng", { Video, None, 0, 0, 0 }},
  { "video/x-ms-asf", { Video, None, 0, 0, 0 }},
  { "video/x-msvideo", { Video, None, 0, 0, 0 }},
  { "video/x-ms-wmv", { Video, None, 0, 0, 0 }},
  { "video/x-ogm", { Video, None, 0, 0, 0 }},
  { "video/x-theora", { Video, None, 0, 0, 0 }},

  { 0, UnspecifiedData}
};
