#ifndef TRANSFORM_H
#define TRANSFORM_H

#include <kfilemetainfo.h>
#include <kstaticdeleter.h>

#include "filter.h"

class KTempFile;
class KTempDir;

namespace Konvert
{
enum TransAction { TransExtract = 0, TransCreate, TransCheck,
                   Nb_TransActions };
struct TransActionData {
  const char *name;
  IOType ioType;
};
extern const TransActionData TRANS_ACTION_DATA[Nb_TransActions];

class ExchangeData
{
public:
  QString dataFilename;
  QValueList<KFileMetaInfoItem> metadata;
};

//-----------------------------------------------------------------------------
class GenericTransform : public QObject
{
  Q_OBJECT
public:
  GenericTransform() {}
  virtual ~GenericTransform() {}

  virtual bool supports(TransAction action,
                        const MimeType &mimetype) const = 0;
  virtual bool doAction(TransAction action, const MimeType &mimetype,
                        const ExchangeData &source, const ExchangeData &dest,
                        Filter *filter) const = 0;
};

//-----------------------------------------------------------------------------
class ProcessTransform : public GenericTransform
{
  Q_OBJECT
public:
  struct SubData {
    bool supported;
    Process::ArgData args;
  };
  static const SubData NOT_SUPPORTED;
  struct Data {
    const char *mimetype;
    Process::Data data;
    const SubData sub[Nb_TransActions];
  };

public:
  ProcessTransform(const Data &data);

  virtual bool supports(TransAction action, const MimeType &mimetype) const;
  virtual bool doAction(TransAction action, const MimeType &mimetype,
                        const ExchangeData &source, const ExchangeData &dest,
                        Filter *filter) const;

protected:
  const Data &_data;
  virtual QStringList args(TransAction action, const QString &source,
                           const QString &dest) const;
  void initSupported() const;
  virtual QStringList findSupportedMimetypes(const QString &output) const;

private:
  mutable bool _initialized;
  mutable BasicMimeTypeList _supported;
};

//-----------------------------------------------------------------------------
typedef QPtrList<GenericTransform> TransformList;
typedef TransformList *TransformListPtr;

class TransformFilter : public Filter
{
  Q_OBJECT
public:
  TransformFilter(KStaticDeleter<TransformList> &sd, TransformListPtr &list,
                  URLType baseType, FileType type, Action action);

  virtual BasicMimeTypeList getSupportedMimetypes(IOType type) const;
  virtual URLType urlType(IOType type, const MimeType &sourceType) const;

protected:
  virtual void startInternal(const QString &source, const MimeType &sourceType,
                             const QString &dest, const MimeType &destType);
  GenericTransform *find(TransAction action, const MimeType &mimetype) const;
  virtual bool isSupported(TransAction action, const MimeType &mimetype) const;
  virtual bool isSupported(Action action, TransAction tAction, IOType type,
                           const MimeType &mimetype) const;
  virtual void fillList(TransformList &list) const = 0;

private:
  URLType _baseType;
  mutable KStaticDeleter<TransformList> &_sd;
  mutable TransformListPtr &_list;

  bool doAction(TransAction action, const MimeType &mimetype,
                const ExchangeData &source, const ExchangeData &dest);
  void initList() const;

  struct Data {
    TransAction action[Nb_IOTypes];
  };
  static const Data DATA[Nb_Actions];
};

} // namespace

#endif
